# polars-coord-transforms

This plugin provides various functions for transforming coordinates which can be useful in robotics, geospatial analysis etc.

The functions are divided among two namespaces: `transform` and `s2`

- `transform` namespace contains functions for converting coordinates from\to map, ecef and lla reference frame.

- `s2` namespace contains functions which allow to work with [S2 Cells](http://s2geometry.io/about/overview)


